@@ -19,7 +19,7 @@ test_that("A basic MNL model converges and creates the output", {
 
     availabilities <- mixl::generate_default_availabilities(Train, logLik_env$num_utility_functions)
 
-    model <- mixl::estimate(logLik_env, est, Train, availabilities = availabilities, control=list(iterlim=4), num_threads = 4)
+    model <- mixl::estimate(logLik_env, est, Train, availabilities = availabilities, num_threads = 1, control=list(iterlim=4))
 
     expect_equal(model$code, 1) #iteration limit
     expect_equal(model$maximum, -2046.955200, tolerance=1e-3)
@@ -32,6 +32,11 @@ test_that("A basic MNL model converges and creates the output", {
 skip_on_cran()
 test_that("A mixed MNL model converges and creates the output", {
   #randomly assign observations to ID's
+  
+  data("Train", package="mlogit")
+  Train$ID <- Train$id
+  Train$CHOICE <- as.numeric(Train$choice)
+  
   mnl_test <- "
     ASC_B_RND 	= @ASC_B 	+ draw_2 * @SIGMA_B;
 
@@ -46,6 +51,9 @@ test_that("A mixed MNL model converges and creates the output", {
   
   availabilities <- mixl::generate_default_availabilities(Train, model_spec$num_utility_functions)
   
+  #weights <- runif(nrow(Train))+1
+  #weights <- weights * (nrow(Train) / sum(weights))
+  
   system.time(model <- mixl::estimate(model_spec, est, Train, availabilities = availabilities, nDraws = 100, num_threads=1))
   
   expect_equal(model$code, 0)
